# chsi 学信网学籍/学历/学位在线验证报告查询

这时一个小工具，用于学信网的学籍/学历/学位在线验证报告查询的获取和解析。

## 安装

```
pip install chsi
```

## 命令行使用

```
python -m chsi <在线验证码>
```

<details>
<summary>返回结果</summary>

```
{
  "status": true,
  "error": "",
  "info": [
    [
      "title",
      "教育部学历证书电子注册备案表"
    ],
    [
      "update_time",
      "2024年01月01日"
    ],
    [
      "姓名",
      "李四"
    ],
    [
      "性别",
      "男"
    ],
    [
      "出生日期",
      "1970年01月01日"
    ],
    [
      "入学日期",
      "1990年09月01日"
    ],
    [
      "毕（结）业日期",
      "1994年07月01日"
    ],
    [
      "学校名称",
      "举例大学"
    ],
    [
      "专业",
      "计算机科学与技术"
    ],
    [
      "学制",
      ""
    ],
    [
      "层次",
      "本科"
    ],
    [
      "学历类别",
      "普通高等教育"
    ],
    [
      "学习形式",
      "普通全日制"
    ],
    [
      "毕（结）业",
      "毕业"
    ],
    [
      "证书编号",
      "1000 0000 0000 0000 00"
    ],
    [
      "校（院）长姓名",
      "张三"
    ]
  ]
}
```

</details>

出错情形
```
{
  "status": false,
  "error": "系统检测到非法访问，不合要求的在线验证码！",
  "info": []
}
```

### 调用

```
from chsi import verify
results = verify("<在线验证码>", lang='CN')
```

